@font-face{font-family:Material Icons;font-style:normal;font-weight:400;src:url(./material-icons.woff2)format("woff2")}.material-icons{letter-spacing:normal;text-transform:none;white-space:nowrap;word-wrap:normal;-webkit-font-feature-settings:"liga";-webkit-font-smoothing:antialiased;direction:ltr;font-family:Material Icons;font-size:24px;font-style:normal;font-weight:400;line-height:1;display:inline-block}
/*# sourceMappingURL=material-icons.css.map*/